/*
Program vznikl na zaklade informaci na strankach
https://learn.sparkfun.com/tutorials/load-cell-amplifier-hx711-breakout-hookup-guide/all

Odkaz na původni zdroj :
 Example using the SparkFun HX711 breakout board with a scale
 By: Nathan Seidle
 SparkFun Electronics
 Date: November 19th, 2014
 License: This code is public domain but you buy me a beer if you use this and we meet someday (Beerware license).


Program pouziva knihovnu: https://github.com/bogde/HX711
Knihovna je distribuovana pod GNU GENERAL PUBLIC LICENSE.

Program je volne k pouziti a autor neprebira zadnou zodpovednost za jeho pouziti.

Puvodni program řešil i kalibraci senzoru. Kalibracni hodnotu jsem zjistil pomoci prikladu pouziti prevodniku HX711, viz vyse.

Kalibraci jsem udelal tak, ze jsem bez zateze vahu vynuloval. Pak jsem vahu zatizil znamou 
hmotmosti a pomoci klavesy + a - jsem menil hodnotu kalibracni konstanty, az byla zobrazovana spravna vaha.
Protože ale kalibracni konstantu nikam neukladal, po zjisteni hodnoty jsem ji zapsal primo do programu.

Samotny program funguje tak, ze po zapnuti se zjisti zakladni hodnota,
ktera se dale pouziva jako hodnota pro nulovou vahu. V hlavni smycce se 120 x nacte hodnota
a zobrazi se prumerna hodnota. Testuje se stisk klavesy n nebo N a po stisku se provede stejna inicializace hodnoty 0
jako po zapnuti napajeni.

POZOR, PRI PROGRAMOVANI MUSI BYT BLUETOOTH MODUL ODPOJENY, PROTOZE PRO PROGRAMOVANI SE POUZIVAJI STEJNE PINY.


 Arduino pin 2 -> HX711 CLK
             3 -> HX711 DOUT
             5V -> VCC
             GND -> GND
 
 Most any pin on the Arduino Uno will be compatible with DOUT/CLK.
 
 The HX711 board can be powered from 2.7V to 5V so the Arduino 5V power should be fine.
 
*/

#include "HX711.h"

#define DOUT  3
#define CLK  2

HX711 scale(DOUT, CLK);

float calibration_factor = 21156;

#define TIMES 120
//float avg_arr[TIMES];
float avg_val;
int i, n;
int null_flag;

void setup() {
  Serial.begin(9600);
  Serial.println("Odstran zatez z vahy pred zapnutim napajeni,");
  Serial.println("nebo stiskni N or n pro vynulovani,");
  Serial.println("pokud je vaha zapnuta a bez zateze");
  Serial.println("pro vynulovani vahy.");

  scale.set_scale();
  scale.tare(); //Nastavit vahu na 0

  long zero_factor = scale.read_average(); //nacti zakladni hodnotu

  scale.set_scale(calibration_factor); //Nastav kalibracni hodnotu
}


void loop() {
  
  //pro zlepseni stability vypisovane hodnoty delam prumer ze 120 hodnot
  avg_val = 0.0;
  for(i = 0; i < TIMES; i++){
    avg_val += scale.get_units();


    //nulovani hodnoty po stisku N nebo n
    if(Serial.available())
    {
      char temp = Serial.read();
      if(temp == 'N' || temp == 'n'){
        scale.set_scale();
        scale.tare(); //Reset the scale to 0

        long zero_factor = scale.read_average(); //Get a baseline reading
        scale.set_scale(calibration_factor); //Adjust to this calibration factor
        Serial.print("null");
        Serial.println();
        //potrebuji zkratit cyklus, aby to reagovalo hned a nepsalo nesmysl
        null_flag = 1,
        i = TIMES;
      }
    }


  }

  //pokud neprobehlo zrovna nulovani, vypisu zmerenou hodnotu
  if(!null_flag){
    Serial.print(avg_val / TIMES, 2);
    Serial.print(" kg");
    Serial.println();
  }
  null_flag = 0;
}





